==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cannons/dialogs_pl.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("Widzisz? Ten statek ma dwa pokłady działowe. To z pewnością był statek wojenny. Kwaśny zapach prochu wciąż unosi się w powietrzu.")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("W wodzie, chciałeś powiedzieć.")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("Czyj to był statek? Może służył pod admirałem Nelsonem... albo kapitanem Hornblowerem.")


dialogId("del-v-splet", "font_big", "No, I think you`re about a hundred years off.")
dialogStr("Chyba się mylisz o jakieś sto lat.")


dialogId("del-v-mec", "font_big", "I have a feeling we`re going to need that sword.")
dialogStr("Mam przeczucie, że będziemy potrzebować tego miecza.")


dialogId("del-m-tus", "font_small", "You and your 'feelings`. Besides, we`re not supposed to be giving any hints.")
dialogStr("Ty i twoje przeczucia... Poza tym, nie powinniśmy podpowiadać.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn`t it?")
dialogStr("To było zbyt proste, czyż nie?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("Czy to rzeczywiście może być takie proste?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Tu musi być jakiś błąd.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cannons/dialogs_pl.lua <==

dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("Widzisz? Ten statek ma dwa pokłady działowe. To z pewnością był statek wojenny. Kwaśny zapach prochu wciąż unosi się w powietrzu.")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("W wodzie, chciałeś powiedzieć.")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("Czyj to był statek? Może służył pod admirałem Nelsonem... albo kapitanem Hornblowerem.")


dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years off.")
dialogStr("Chyba się mylisz o jakieś sto lat.")


dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")
dialogStr("Mam przeczucie, że będziemy potrzebować tego miecza.")


dialogId("del-m-tus", "font_small", "You and your 'feelings’. Besides, we’re not supposed to be giving any hints.")
dialogStr("Ty i twoje przeczucia... Poza tym, nie powinniśmy podpowiadać.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")
dialogStr("To było zbyt proste, czyż nie?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("Czy to rzeczywiście może być takie proste?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Tu musi być jakiś błąd.")
